@@ -20,6 +20,11 @@
 #include "StopWatch.h"
 
 #include <Lum/Base/String.h>
+#include <iostream>
+
+static Lum::OS::Display::FontType fontType  = Lum::OS::Display::fontTypeProportional;
+//static Lum::OS::Display::FontType fontType  = Lum::OS::Display::fontTypeFixed;
+static unsigned long              fontStyle = Lum::OS::Font::normal;
 
 StopWatch::StopWatch()
  : clickAction(new Lum::Model::Action()),
@@ -29,11 +34,11 @@ StopWatch::StopWatch()
    showInvert(false)
 {
   if (Lum::OS::display->GetType()==Lum::OS::Display::typeTextual) {
-    minFont=Lum::OS::display->GetFont(Lum::OS::Display::fontScaleNormal);
+    minFont=Lum::OS::display->GetFont(fontType,Lum::OS::Display::fontScaleNormal);
     font=minFont;
     }
   else {
-    minFont=Lum::OS::display->GetFont(500);
+    minFont=Lum::OS::display->GetFont(fontType,500);
     font=minFont;
   }
 
@@ -68,24 +73,24 @@ void StopWatch::CalcSize()
 
   w=0;
   for (size_t i=1; i<=9; i++) {
-    minFont->StringExtent(Lum::Base::NumberToWString(i),extent,Lum::OS::Font::bold);
+    minFont->StringExtent(Lum::Base::NumberToWString(i),extent,fontStyle);
 
     w=std::max(w,extent.width);
   }
 
-  minFont->StringExtent(L":",extent,Lum::OS::Font::bold);
+  minFont->StringExtent(L":",extent,fontStyle);
 
   minWidth=4*w+extent.width;
   minHeight=minFont->height;
 
   w=0;
   for (size_t i=1; i<=9; i++) {
-    font->StringExtent(Lum::Base::NumberToWString(i),extent,Lum::OS::Font::bold);
+    font->StringExtent(Lum::Base::NumberToWString(i),extent,fontStyle);
 
     w=std::max(w,extent.width);
   }
 
-  font->StringExtent(L":",extent,Lum::OS::Font::bold);
+  font->StringExtent(L":",extent,fontStyle);
 
   width=4*w+extent.width;
   height=font->height;
@@ -101,19 +106,19 @@ Lum::OS::Font* StopWatch::FindFont()
     Lum::OS::FontRef tmpFont;
     size_t           w=0,h=0;
 
-    tmpFont=Lum::OS::display->GetFontByPixel(Lum::OS::Display::fontTypeProportional,fontSize);
+    tmpFont=Lum::OS::display->GetFontByPixel(fontType,fontSize);
 
     if (tmpFont.Valid()) {
       Lum::OS::FontExtent extent;
 
       for (size_t i=1; i<=9; i++) {
-        tmpFont->StringExtent(Lum::Base::NumberToWString(i),extent,Lum::OS::Font::bold);
+        tmpFont->StringExtent(Lum::Base::NumberToWString(i),extent,fontStyle);
 
         w=std::max(w,extent.width);
         h=std::max(h,extent.height);
       }
 
-      tmpFont->StringExtent(L":",extent,Lum::OS::Font::bold);
+      tmpFont->StringExtent(L":",extent,fontStyle);
       h=std::max(h,extent.height);
 
       if (4*w+extent.width<=width && h<=height) {
@@ -148,7 +153,7 @@ void StopWatch::Draw(int x, int y, size_t w, size_t h)
   Lum::OS::DrawInfo   *draw=GetDrawInfo();
   Lum::OS::FontExtent extent;
 
-  draw->PushFont(font,Lum::OS::Font::bold);
+  draw->PushFont(font,fontStyle);
 
   if (alarm && showInvert) {
     draw->PushForeground(alarmColor);
@@ -164,7 +169,7 @@ void StopWatch::Draw(int x, int y, size_t w, size_t h)
     draw->PushForeground(Lum::OS::Display::textColor);
   }
 
-  font->StringExtent(text,extent,Lum::OS::Font::bold);
+  font->StringExtent(text,extent,fontStyle);
 
   draw->DrawString(this->x+(width-extent.width)/2,
                    this->y+(height-extent.height)/2+extent.ascent,
